function dxdt = predprey(t,x,a,b,c,d)
% 
% Calculates the right-hand-side for a system of 
% 2 ODEs (Lotka-Volterra equations):
%    dxdt = ax - bxy
%    dydt = -cy + dxy
%
% input:
%    t: time
%    x(1:2)      : 2-element vector representing (x,y)
%    a, b, c, d  : parameter values
% output:
%    dxdt(1:2)   : 2-element vector of rhs
%
dxdt=zeros(2,1);
dxdt(1) = a*x(1) - b*x(1)*x(2);
dxdt(2) = -c*x(2) + d*x(1)*x(2);
